pub struct PreviousGtidsEvent<'a> { /* private fields */ }Expand description
Previous GTIDs Event.
Contains the complete GTID set of all transactions committed prior to the current binlog file. Appears near the start of each binlog file.
Supports both the legacy untagged format and the tagged format introduced in MySQL 8.4+.
Implementations
Sourceimpl<'a> PreviousGtidsEvent<'a>
impl<'a> PreviousGtidsEvent<'a>
Sourcepub fn new(sids: Vec<PreviousGtidsSid<'a>>) -> Self
pub fn new(sids: Vec<PreviousGtidsSid<'a>>) -> Self
Creates a new event.
Sourcepub fn sids(&self) -> &[PreviousGtidsSid<'a>]
pub fn sids(&self) -> &[PreviousGtidsSid<'a>]
Returns the SID entries.
Sourcepub fn into_owned(self) -> PreviousGtidsEvent<'static>
pub fn into_owned(self) -> PreviousGtidsEvent<'static>
Returns a 'static version of self.