pub enum AuthPlugin<'a> {
MysqlOldPassword,
MysqlClearPassword,
MysqlNativePassword,
CachingSha2Password,
Ed25519,
MariadbParsec {
iterations: u32,
ext_salt: [u8; 18],
},
Other(Cow<'a, [u8]>),
}Expand description
Authentication plugin
Variants
MysqlOldPassword
Old Password Authentication
MysqlClearPassword
Client-Side Cleartext Pluggable Authentication
MysqlNativePassword
Legacy authentication plugin
CachingSha2Password
Default since MySql v8.0.4
Ed25519
MariaDB’s Ed25519 based authentication
This plugin is known to the library but the actual support is enabled
by the client_ed25519 feature.
MariadbParsec
MariaDB’s Parsec(Password Authentication using Response Signed with Eliptic Curve) authentication
Actual support is enabled by the client_parsec feature.
Other(Cow<'a, [u8]>)
Implementations
Sourceimpl<'a> AuthPlugin<'a>
impl<'a> AuthPlugin<'a>
pub fn from_bytes(name: &'a [u8]) -> AuthPlugin<'a>
pub fn as_bytes(&self) -> &[u8] ⓘ
pub fn into_owned(self) -> AuthPlugin<'static>
pub fn borrow(&self) -> AuthPlugin<'_>
Sourcepub fn gen_data<'b>(
&self,
pass: Option<&'b str>,
nonce: &[u8],
) -> Option<AuthPluginData<'b>>
pub fn gen_data<'b>( &self, pass: Option<&'b str>, nonce: &[u8], ) -> Option<AuthPluginData<'b>>
Generates auth plugin data for this plugin.
It’ll generate None if password is None or empty.
Note, that you should trim terminating null character from the nonce.
Panic
AuthPlugin::Ed25519will panic ifclient_ed25519feature is disabled.AuthPlugin::MariadbParsecwill panic ifclient_parsecfeature is disabled.
Sourcepub fn read_add_data(&mut self, payload: &[u8]) -> Option<()>
pub fn read_add_data(&mut self, payload: &[u8]) -> Option<()>
Reads additional (packet) data required for authentication data generation.
Currently only needed for Parseec plugin to read the result of additional packets exchange with the server.