ComStmtBulkExecuteRequestBuilder

Struct ComStmtBulkExecuteRequestBuilder 

pub struct ComStmtBulkExecuteRequestBuilder<'a> { /* private fields */ }
Sends array of parameters to the server for the bulk execution of a prepared statement with COM_STMT_BULK_EXECUTE command. This command is MariaDB only and may not be used for queries w/out parameters and with empty parameter sets.

Implementations

Source

impl ComStmtBulkExecuteRequestBuilder<'_>

pub fn new( stmt_id: u32, max_allowed_packet: usize, ) -> ComStmtBulkExecuteRequestBuilder<'static>

pub fn with_named_params<'a>( self, named_params: Option<&'a [Vec<u8>]>, ) -> ComStmtBulkExecuteRequestBuilder<'a>

Use named parameters in the same order they were given in the SQL statement.

pub fn with_results(self) -> Self

Send [SEND_UNIT_RESULTS] flag to the server.

This feature is available since MariaDb v11.5.1 and requires MARIADB_CLIENT_BULK_UNIT_RESULTS capability from the server.

pub fn add_params( &mut self, params: impl Into<Params>, ) -> Result<Option<Vec<Value>>, BulkExecuteRequestBuilderError>

pub fn add_row( &mut self, params: Vec<Value>, ) -> Result<Option<Vec<Value>>, BulkExecuteRequestBuilderError>

Adds a new row of parameters to the bulk execute request.

Returns row back if adding it would exceed the max allowed packet size — practically this means that you should call ComStmtBulkExecuteRequestBuilder::build to consume all the rows added so far and then continue adding more rows to the next bulk request starting from this returned row.

Error

This function will emit an error if params’ arity differs from previous rows added to this builder or if row is larger than the max payload length (max allowed packet - 4)

pub fn has_rows(&self) -> bool

pub fn build( &mut self, ) -> Result<ComStmtBulkExecuteRequest<'static>, BulkExecuteRequestError>

Builds COM_STMT_BULK_EXECUTE consuming rows added so far.

After the call you can continue using ComStmtBulkExecuteRequestBuilder::add_row to build next bulk request for this statement.

Error

This will error if no rows was added to the builder.

pub fn build_params_iter( &mut self, input: impl IntoIterator<Item = impl Into<Params>>, ) -> impl Iterator<Item = Result<ComStmtBulkExecuteRequest<'static>, BulkExecuteRequestBuilderError>>

pub fn build_iter( &mut self, input: impl IntoIterator<Item = Vec<Value>>, ) -> impl Iterator<Item = Result<ComStmtBulkExecuteRequest<'static>, BulkExecuteRequestBuilderError>>

It’s a convenient wrapper over ComStmtBulkExecuteRequestBuilder::add_row and ComStmtBulkExecuteRequestBuilder::build that converts a rows iterator to a bulk requests iterator.

Error

This won’t error if the input iterator contains no rows — it’ll just emit no bulk requests but the iterator will emit an error if it encounters a row with different arity.